==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/runnables/ugene/corelibs/U2Gui/CreateRulerDialogFiller.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include <primitives/GTLineEdit.h>
#include <primitives/GTSpinBox.h>
#include <primitives/GTWidget.h>

#include <QApplication>

#include "CreateRulerDialogFiller.h"

namespace U2 {

#define GT_CLASS_NAME "CreateRulerDialogFiller"
#define GT_METHOD_NAME "commonScenario"

CreateRulerDialogFiller::CreateRulerDialogFiller(GUITestOpStatus &os, QString _rulerName, int _startPos)
    : Filler(os, "CreateRulerDialog"),
      rulerName(_rulerName),
      startPos(_startPos) {
}

CreateRulerDialogFiller::CreateRulerDialogFiller(GUITestOpStatus &os, CustomScenario *c)
    : Filler(os, "CreateRulerDialog", c),
      startPos(0) {
}

void CreateRulerDialogFiller::commonScenario() {
    QWidget *dialog = QApplication::activeModalWidget();
    GT_CHECK(nullptr != dialog, "activeModalWidget is NULL");

    QLineEdit *nameEdit = GTWidget::findExactWidget<QLineEdit *>(os, "nameEdit", dialog);
    GTLineEdit::setText(os, nameEdit, rulerName);

    QSpinBox *spinBox = GTWidget::findExactWidget<QSpinBox *>(os, "spinBox", dialog);
    GTSpinBox::setValue(os, spinBox, startPos, GTGlobals::UseKeyBoard);

    GTUtilsDialog::clickButtonBox(os, QDialogButtonBox::Ok);
}

#undef GT_METHOD_NAME
#undef GT_CLASS_NAME

}  // namespace U2

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/GUITestBase/src/runnables/ugene/corelibs/U2Gui/CreateRulerDialogFiller.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include <primitives/GTLineEdit.h>
#include <primitives/GTSpinBox.h>
#include <primitives/GTWidget.h>

#include <QApplication>

#include "CreateRulerDialogFiller.h"

namespace U2 {

#define GT_CLASS_NAME "CreateRulerDialogFiller"

CreateRulerDialogFiller::CreateRulerDialogFiller(QString _rulerName, int _startPos)
    : Filler("CreateRulerDialog"),
      rulerName(_rulerName),
      startPos(_startPos) {
}

CreateRulerDialogFiller::CreateRulerDialogFiller(CustomScenario* c)
    : Filler("CreateRulerDialog", c),
      startPos(0) {
}

void CreateRulerDialogFiller::commonScenario() {
    QWidget* dialog = GTWidget::getActiveModalWidget();

    GTLineEdit::setText("nameEdit", rulerName, dialog);

    auto spinBox = GTWidget::findSpinBox("spinBox", dialog);
    GTSpinBox::setValue(spinBox, startPos, GTGlobals::UseKeyBoard);

    GTUtilsDialog::clickButtonBox(QDialogButtonBox::Ok);
}

#undef GT_CLASS_NAME

}  // namespace U2
